# TransientAnalyzer

Gaussian process regression-based analysis of noisy transient signals.

**Documentation and example:** [ReadTheDocs](http://transientanalyzer.readthedocs.org)

**Requirements:** 
[NumPy](http://www.numpy.org/), [SciPy](http://www.scipy.org/), [GPFlow](https://www.gpflow.org/), [Pandas](http://https://pandas.pydata.org/), [PyBaselines](https://pybaselines.readthedocs.io/) Python >= 3.7

**Installation:** ``pip install TransientAnalyzer``

**Authors:**  Iuliia Baglaeva (iuliia.baglaeva@savba.sk), Bogdan Iaparov, Ivan Zahradník and Alexandra Zahradníková.
